@@ -4,8 +4,8 @@ from sklearn.ensemble import RandomForestClassifier
 from sklearn.model_selection import GridSearchCV
 from yupi import Trajectory
 
+from pactus import featurizers
 from pactus.dataset import Data
-from pactus.features.featurizer import Featurizer
 from pactus.models import Model
 
 NAME = "random_forest"
@@ -14,7 +14,7 @@ NAME = "random_forest"
 class RandomForestModel(Model):
     """Implementation of a Random Forest Classifier."""
 
-    def __init__(self, featurizer: Featurizer, **kwargs):
+    def __init__(self, featurizer: featurizers.Featurizer, **kwargs):
         super().__init__(NAME)
         self.featurizer = featurizer
         self.rfc = RandomForestClassifier(**kwargs)
@@ -23,12 +23,12 @@ class RandomForestModel(Model):
 
     def train(self, data: Data, cross_validation: int = 0):
         self.set_summary(cross_validation=cross_validation)
-        x_data = self.featurizer.compute(data)
+        x_data = data.featurize(self.featurizer)
         self.grid = GridSearchCV(self.rfc, {}, cv=cross_validation, verbose=3)
         self.grid.fit(x_data, data.labels)
 
     def predict(self, data: Data) -> List[Any]:
-        x_data = self.featurizer.compute(data)
+        x_data = data.featurize(self.featurizer)
         return self.grid.predict(x_data)
 
     def predict_single(self, traj: Trajectory) -> Any:
